/******************************************************************************
 *
 * $Workfile: uart.h $
 *
 * This module is the header file for uart.c
 *
 * $History: uart.h $
 *
 *****************************************************************************/
#ifndef INC_UART_H
#define INC_UART_H

#ifndef size_t
#include <stddef.h>
#endif


/* Define the host sequence requests */
enum HSQ_UART { no_parity = 0, no_parity1, even_parity, odd_parity };

/* Function prototypes */

/* Initialize the transmit and receive channels, setting the baud rate and
 * parity. One stop bit will be presumed, because the UART cannot handle
 * anything else on a transmit channel, so we'll keep the receive channel
 * consistent with it.
 */
void tpu_uart_init(unsigned int baud, int parity);

/* Put a character into the channel transmit queue.
 * Return 0 on success, -1 on error (queue full).
 */
int tpu_uart_putc(char character);

/* Get available space in uart transmit queue
 */
size_t tpu_uart_space(void);

/* write NULL terminated 'string' to the uart output
 * queue, returning a pointer to the next character
 * to be written.  (\0 if full string is written)
 */
char *tpu_uart_puts(char *string);

/* flush the UART transmit buffer
 */
void tpu_uart_flush_tx(void);

/* Write 'count' characters from 'buffer' to the uart
 * output queue.
 * Return 0 on success, -1 if insufficient room, -2 on error
 * NOTE: if insufficient room, no characters are written.
 */
int tpu_uart_write(char *buffer, size_t count);

/* Get a character via a receive channel.
 * Return character on success, -1 if no character is available.
 */
int tpu_uart_getc(void);

#endif
